@@ -13,8 +13,6 @@ import bz2
 import gzip
 import lzma
 
-from texta_face_analyzer.face_analyzer import FaceAnalyzer
-
 from texta_parsers.email_parser import EmailParser
 from texta_parsers.settings import META_FIELD, FACE_VECTOR_FIELD_NAME
 from texta_parsers.tools.extension import Extension
@@ -28,9 +26,6 @@ from . import exceptions
 # for digidoc parser
 FNULL = open(os.devnull, "w")
 
-# initiate face analyzer
-FACE_ANALYZER = FaceAnalyzer()
-
 
 class DocParser:
     
@@ -209,7 +204,9 @@ class DocParser:
         output_document = {}
         # extract faces if an image
         if document["extension"] in Extension.IMAGE_EXTENSIONS:
-            face_vectors = FACE_ANALYZER.vectorize_photo(document["path"])
+            # import here so we won't die on init if analyzer not installed
+            from texta_face_analyzer.face_analyzer import FaceAnalyzer
+            face_vectors = FaceAnalyzer().vectorize_photo(document["path"])
             if face_vectors:
                 output_document[FACE_VECTOR_FIELD_NAME] = [{"name": "UNKOWN_FACE", "vector": v} for v in face_vectors]
         # extract text using TIKA
