@@ -18,7 +18,10 @@ class Extension:
     
     #ARCHIVE_EXTENSIONS = (".zip", ".tar", ".bz2", ".gz") + DIGIDOC_EXTENSIONS
     #requires patool to be installed
-    ARCHIVE_EXTENSIONS = (".7z", ".bz2", ".gz", ".lrz", ".lha", ".lzh", ".lz", ".rar", ".rz", ".tar", ".xz", ".zip") + DIGIDOC_EXTENSIONS
+    #.rz - requires rzip
+    #.lz - requires lzip
+    # ".lrz", ".lha", ".lzh" - what to use?
+    ARCHIVE_EXTENSIONS = (".7z", ".bz2", ".gz", ".rar", ".tar", ".xz", ".zip") + DIGIDOC_EXTENSIONS
     # union of all known extensions used in parsing
     KNOWN_EXTENSIONS = ARCHIVE_EXTENSIONS + DOC_EXTENSIONS + AUDIO_EXTENSIONS + COLLECTION_EXTENSIONS + IMAGE_EXTENSIONS + EMAIL_EXTENSIONS
     # these files are always identified by extension, because magic misidentifies them or because it is particularly important that these 
